@@ -1,19 +1,13 @@
-import sys
-
 import requests
 from bs4 import BeautifulSoup
 
-console_mapper = {
-    "gba": 48,
-    "genesis": 98,
-    "n64": 75,
-    "snes": 110,
-}
+from .config import BASE_URL
+from .consoles import consoles
 
 
 def verify_console_name(console_name):
     try:
-        console_code = console_mapper[console_name]
+        console_code = consoles[console_name]
     except KeyError:
         raise KeyError(f"Console {console_name} is not available.")
 
@@ -24,7 +18,7 @@ def search(console_code, query, order_by="downloads", asc=False, page=0):
     order = f"{order_by}${'ASC' if asc else 'DESC'}"
 
     response = requests.post(
-        "https://roms-download.com/ajax.php?m=roms_j",
+        f"{BASE_URL}/ajax.php?m=roms_j",
         data={
             "sort": order,
             "page": page,
@@ -49,7 +43,7 @@ def parse_row(row):
         rating=columns[2].text.strip("\n"),
         downloads=columns[3].text.strip("\n"),
         size=columns[4].text.strip("\n"),
-        link=f"https://roms-download.com{columns[0].find('a')['href']}",
+        link=f"{BASE_URL}{columns[0].find('a')['href']}",
     )
 
     return parsed_row
